@@ -3,6 +3,7 @@ use std::ops::Neg;
 use auto_ops::*;
 
 #[derive(Debug, Clone, Copy, PartialEq)]
+#[cfg_attr(feature="serde", derive(serde::Serialize, serde::Deserialize))]
 #[repr(C)]
 pub struct Vec3 {
     pub x: f32,
@@ -96,6 +97,12 @@ impl Neg for Vec3 {
     }
 }
 
+impl From<[f32; 3]> for Vec3 {
+    fn from(d: [f32; 3]) -> Self {
+        Self{x: d[0], y: d[1], z: d[2]}
+    }
+}
+
 
 #[cfg(test)]
 mod tests {
